@@ -6,7 +6,7 @@ test_data2 <- data.frame(g = c(rep(1, 1e4), rep(2, 1e4)),
 
 test_that("Area under the curve computes and outputs correctly", {
 	expect_true(round(hedg_g(score ~ g, test_data1, 1, tidy = FALSE), 1) == 0)
-	expect_true(round(hedg_g(score ~ g, test_data2, 1, tidy = FALSE), 1) == -1)
+	expect_true(round(hedg_g(score ~ g, test_data2, 1, tidy = FALSE), 1) == 1)
 	expect_output(str(hedg_g(score ~ g, test_data1)), "data.frame")
 	expect_output(str(hedg_g(score ~ g, test_data1, tidy = FALSE)), 
 		"Named num")
